[Replace this with a description of the PR as appropriate, and please tick off the 'Due diligence' tasks below ready for review.]

## Due diligence

- [ ] Assign PR to author.
- [ ] Ensure status checks are passing (linting, type checking and unit tests can all be run locally with `poe checks`).
- [ ] Add a label(s) to the PR to indicate its broad intention.
- [ ] Add unit tests for the new fix/feature (if applicable).
